@@ -1000,7 +1000,6 @@ class RemoteAudioTrackStatsInner(ctypes.Structure):
             stats.received_bytes
         )
 
-
 class EncodedAudioFrameInfoInner(ctypes.Structure):
     _fields_ = [
         ('speech', ctypes.c_int),
@@ -1008,7 +1007,8 @@ class EncodedAudioFrameInfoInner(ctypes.Structure):
         ('sample_rate_hz', ctypes.c_int),
         ('samples_per_channel', ctypes.c_int),
         ('send_even_if_empty', ctypes.c_int),
-        ('number_of_channels', ctypes.c_int)
+        ('number_of_channels', ctypes.c_int),
+        ('capture_time_ms', ctypes.c_int64)
     ]
 
     @staticmethod
@@ -1019,7 +1019,8 @@ class EncodedAudioFrameInfoInner(ctypes.Structure):
             info.sample_rate,
             info.samples_per_channel,
             info.send_even_if_empty,
-            info.number_of_channels
+            info.number_of_channels,
+            info.capture_time_ms
         )
 
 
@@ -1067,6 +1068,10 @@ class AudioFrameInner(ctypes.Structure):
         ("buffer", ctypes.c_void_p),
         ("render_time_ms", ctypes.c_int64),
         ("avsync_type", ctypes.c_int),
+        ("presentation_ms", ctypes.c_int64),
+        ("audio_track_number", ctypes.c_int),
+        ("rtp_timestamp", ctypes.c_uint32),
+       
         ("far_field_flag", ctypes.c_int),
         ("rms", ctypes.c_int),
         ("voice_prob", ctypes.c_int),
@@ -1084,6 +1089,9 @@ class AudioFrameInner(ctypes.Structure):
             buffer=bytearray(ctypes.string_at(self.buffer, self.samples_per_channel * self.bytes_per_sample * self.channels)),
             render_time_ms=self.render_time_ms,
             avsync_type=self.avsync_type,
+            presentation_ms=self.presentation_ms,
+            audio_track_number=self.audio_track_number,
+            rtp_timestamp=self.rtp_timestamp,
             far_field_flag=self.far_field_flag,
             rms=self.rms,
             voice_prob=self.voice_prob,
@@ -1102,6 +1110,9 @@ class AudioFrameInner(ctypes.Structure):
             ctypes.cast(frame.buffer, ctypes.c_void_p),
             frame.render_time_ms,
             frame.avsync_type,
+            frame.presentation_ms,
+            frame.audio_track_number,
+            frame.rtp_timestamp,
             frame.far_field_flag,
             frame.rms,
             frame.voice_prob,
@@ -1133,6 +1144,11 @@ class AgoraServiceConfigInner(ctypes.Structure):
 
         ('use_string_uid', ctypes.c_int),
         ('domain_limit', ctypes.c_int),
+        ('log_level', ctypes.c_int),
+        ('log_file_path', ctypes.c_char_p),
+        ('log_file_size_kb', ctypes.c_uint32),
+        ('data_dir', ctypes.c_char_p),
+        ('config_dir', ctypes.c_char_p),
     ]
 
     def get(self):
@@ -1146,7 +1162,12 @@ class AgoraServiceConfigInner(ctypes.Structure):
             channel_profile=self.channel_profile,
             audio_scenario=self.audio_scenario,
             use_string_uid=self.use_string_uid,
-            domain_limit=self.domain_limit
+            domain_limit=self.domain_limit,
+            log_level=self.log_level,
+            log_path=self.log_file_path.decode() if self.log_file_path else "",
+            log_file_size_kb=self.log_file_size_kb,
+            data_dir=self.data_dir.decode() if self.data_dir else "",
+            config_dir=self.config_dir.decode() if self.config_dir else ""
         )
 
     @staticmethod
@@ -1156,12 +1177,17 @@ class AgoraServiceConfigInner(ctypes.Structure):
             config.enable_audio_device,
             config.enable_video,
             config.context,
-            config.appid.encode(),
+            config.appid.encode() if config.appid else None,
             config.area_code,
             config.channel_profile,
             config.audio_scenario,
             config.use_string_uid,
-            config.domain_limit
+            config.domain_limit,
+            config.log_level,
+            config.log_path.encode() if config.log_path else None,
+            config.log_file_size_kb,
+            config.data_dir.encode() if config.data_dir else None,
+            config.config_dir.encode() if config.config_dir else None
         )
 
 
@@ -1177,7 +1203,8 @@ class EncodedVideoFrameInfoInner(ctypes.Structure):
         ("capture_time_ms", ctypes.c_int64),
         ("decode_time_ms", ctypes.c_int64),
         ("uid", ctypes.c_uint),
-        ("stream_type", ctypes.c_int)
+        ("stream_type", ctypes.c_int),
+        ("presentation_ms", ctypes.c_int64)
     ]
 
     def get(self):
@@ -1192,7 +1219,8 @@ class EncodedVideoFrameInfoInner(ctypes.Structure):
             capture_time_ms=self.capture_time_ms,
             decode_time_ms=self.decode_time_ms,
             uid=self.uid,
-            stream_type=self.stream_type
+            stream_type=self.stream_type,
+            presentation_ms=self.presentation_ms
         )
 
     @staticmethod
@@ -1208,7 +1236,8 @@ class EncodedVideoFrameInfoInner(ctypes.Structure):
             info.capture_time_ms,
             info.decode_time_ms,
             info.uid,
-            info.stream_type
+            info.stream_type,
+            info.presentation_ms
         )
     
 
@@ -1249,3 +1278,94 @@ class EncryptionConfigInner(ctypes.Structure):
             encryption_key,
             encryption_kdf_salt
         )
+
+
+class CapabilityItemInner(ctypes.Structure):
+    _fields_ = [
+        ("id", ctypes.c_uint8),
+        ("name", ctypes.c_char_p)
+    ]
+
+    def get(self):
+        return CapabilityItem(
+            id=self.id,
+            name=self.name.decode() if self.name else ""
+        )
+
+    @staticmethod
+    def create(item: CapabilityItem) -> 'CapabilityItemInner':
+        return CapabilityItemInner(
+            item.id,
+            item.name.encode() if item.name else None
+        )
+
+
+class CapabilityItemMapInner(ctypes.Structure):
+    _fields_ = [
+        ("item", ctypes.POINTER(CapabilityItemInner)),
+        ("size", ctypes.c_size_t)
+    ]
+
+    def get(self):
+        items = []
+        if self.item and self.size > 0:
+            for i in range(self.size):
+                items.append(self.item[i].get())
+        return CapabilityItemMap(
+            item=items,
+            size=self.size
+        )
+
+    @staticmethod
+    def create(item_map: CapabilityItemMap) -> 'CapabilityItemMapInner':
+        if item_map.item and len(item_map.item) > 0:
+            items_array = (CapabilityItemInner * len(item_map.item))()
+            for i, item in enumerate(item_map.item):
+                items_array[i] = CapabilityItemInner.create(item)
+            items_ptr = ctypes.cast(items_array, ctypes.POINTER(CapabilityItemInner))
+        else:
+            items_ptr = ctypes.POINTER(CapabilityItemInner)()
+        
+        return CapabilityItemMapInner(
+            items_ptr,
+            len(item_map.item) if item_map.item else 0
+        )
+
+
+class CapabilitiesInner(ctypes.Structure):
+    _fields_ = [
+        ("item_map", ctypes.POINTER(CapabilityItemMapInner)),
+        ("capability_type", ctypes.c_int)
+    ]
+
+    def get(self):
+        return Capabilities(
+            item_map=self.item_map.contents.get() if self.item_map else None,
+            capability_type=self.capability_type
+        )
+
+    @staticmethod
+    def create(capabilities: Capabilities) -> 'CapabilitiesInner':
+        item_map_ptr = None
+        if capabilities.item_map:
+            item_map_inner = CapabilityItemMapInner.create(capabilities.item_map)
+            item_map_ptr = ctypes.pointer(item_map_inner)
+        
+        return CapabilitiesInner(
+            item_map_ptr,
+            capabilities.capability_type
+        )
+
+
+
+class CapabilitiesItemMapInner(ctypes.Structure):
+    _fields_ = [
+        ("item", ctypes.POINTER(CapabilityItemInner)),
+        ("size", ctypes.c_size_t)
+    ]
+
+    def get(self):
+        return CapabilitiesItemMap(
+            item=self.item,
+            size=self.size
+        )
\ No newline at end of file
