@@ -1,3 +1,4 @@
+from ._ctypes_handle._ctypes_data import *
 import time
 import ctypes
 from .agora_base import *
@@ -54,12 +55,19 @@ agora_local_audio_track_set_send_delay_ms = agora_lib.agora_local_audio_track_se
 agora_local_audio_track_set_send_delay_ms.restype = None
 agora_local_audio_track_set_send_delay_ms.argtypes = [AGORA_HANDLE, ctypes.c_int]
 
+
+# AGORA_API_C_VOID agora_local_audio_track_destroy(AGORA_HANDLE agora_local_audio_track);
+agora_local_audio_track_destroy = agora_lib.agora_local_audio_track_destroy
+agora_local_audio_track_destroy.restype = None
+agora_local_audio_track_destroy.argtypes = [AGORA_HANDLE]
+
+
 class LocalAudioTrack:
     def __init__(self, track_handle):
         self.track_handle = track_handle
 
     def set_enabled(self, enable):
-         agora_local_audio_track_set_enabled(self.track_handle, enable)        
+        agora_local_audio_track_set_enabled(self.track_handle, enable)
 
     def is_enabled(self):
         enabled = ctypes.c_int()
@@ -106,10 +114,9 @@ class LocalAudioTrack:
         return ret
 
     def release(self):
-        pass
-        # if self.track_handle:
-        #     agora_local_audio_track_release(self.track_handle)
-        #     self.track_handle = None
+        if self.track_handle:
+            agora_local_audio_track_destroy(self.track_handle)
+            self.track_handle = None
 
-    def set_send_delay_ms(self, delay_ms:int):
-        agora_local_audio_track_set_send_delay_ms(self.track_handle, delay_ms)
\ No newline at end of file
+    def set_send_delay_ms(self, delay_ms: int):
+        agora_local_audio_track_set_send_delay_ms(self.track_handle, delay_ms)
